3. Contributing — Django Shop v0.0.0 documentation

### Navigation

- index
- next |
- previous |
- Django Shop v0.0.0 documentation »

# 3. Contributing

## 3.1. Running tests

It’s important to run tests before commiting :) Hopefully, we provided a small yet handly script to do it for you! Simply invoke runtests.sh on a unix platform and you should be all set.

### 3.1.1. Options

While a simple tool, runtests provides the following options:

- “–with-coverage” : run the tests using coverage and let the coverage results be displayed in your default browser
- “–with-docs” : run the tests and generate the documentation (the one you’re reading right now).

## 3.2. Community

Most of the discussion abround django SHOP takes place on IRC (Internet Relay Chat), on the freenode servers on the #django-shop channel

We also have a mailing list and a google group:

    http://groups.google.com/group/django-shop

## 3.3. Code guidelines

- As most projects, we try to follow PEP8 as closely as possible
- Most pull requests will be rejected without proper unit testing
- Generally we like to discuss new features before they are merged in, but this is a somewhat flexible rule :)

### Navigation

- index
- next |
- previous |
- Django Shop v0.0.0 documentation »